// pages/order/order.js
const app = getApp()
const wxService = require('../../utils/wxService')
const utils = require('../../utils/util')
const envInfo = require('../../config/index').envInfo

wxService.page({
  /**
   * 页面的初始数据
   */
  data: {
    showApplyRefundModal: false,
    // 订单状态(C:取消;N:新建,P:已支付;D:已发货;R:已收货)
    swiperItem: [
      {
        type: '1',
        status: '',
        name: '全部',
        hasTips : false
      },
      {
        type: '2',
        status: 'N',
        name: '待付款', // 新建
        hasTips: false
      },
      {
        type: '3',
        status: 'P',
        name: '待发货',
        hasTips: false
      },
      {
        type: '4',
        status: 'D',
        name: '待收货',
        hasTips: false
      },
      {
        type: '5',
        status: 'RF',
        name: '退款/售后',
        hasTips: false
      }
    ],
    currentIndex: 1,
    pageNo: 1,
    pageSize: 10,
    noMoreFlag: false,
    orderList: null,
    totalPages: 0,
    subImgs: [],
    status: '',  // 订单状态(C:取消;N:新建,P:已支付;D:已发货;R:已收货)
    no_data: true,
    currentTradeId: '',
    refundId : ''
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    wx.hideShareMenu()
  },

  //复制
  onTapCopy(e){
    wx.setClipboardData({
      //准备复制的数据
      data: e.currentTarget.dataset.no,
      success: function (res) {
        wx.showToast({
          title: '复制成功',
          icon: 'none'
        });
      }
    });
  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {
    const { currentIndex } = this.data;

    this.handleOrderStatus(this.options.orderStatus)
    if (currentIndex == 5) {
      this.getRefundList(this.data.pageNo, this.data.pageSize)
    } else {
      this.setData({
        pageNo: 1,
        pageSize: 10
      }, () => {
        this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
      })
    }
  },
  //处理订单状态
  handleOrderStatus(orderStatus){
    if(orderStatus){
      this.data.swiperItem.forEach(item => {
        if (item.status == orderStatus){
          this.data.currentIndex = item.type;
          this.data.status = orderStatus;
        }
      });

      this.setData({
        currentIndex : this.data.currentIndex
      });
    }
  },
  // 确认收货
  handelConfirmReceipt(e) {
    const { id } = e.currentTarget.dataset
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wxService.post(`/sale/trade/buyer/confirm/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: `您已确认收货!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        } else {
          wx.showToast({
            title: `确认收货失败!`,
            icon: 'none'
          })
          setTimeout(() => {
            this.onShow()
          }, 200)
        }
      }
    })
  },
  // 删除订单
  handelDelOrder(e) {
    let _this = this;
    wx.showModal({
      title: '订单删除提示',
      content: '确认删除此订单？',
      showCancel: true,
      cancelText: '取消',
      confirmText: '删除',
      confirmColor: '#cb3c3c',
      success: function (modalRes) {
        if (modalRes.confirm) {
          const { id } = e.currentTarget.dataset
          wx.showLoading({
            title: '订单删除中..',
            mask: true
          })
          wxService.post(`/sale/trade/buyer/delete/${id}`).then(res => {
            if (res) {
              const { result } = res.data
              if (result == 0) {
                wx.hideLoading()
                wx.showToast({
                  title: `删除成功!`,
                  icon: 'none'
                })
                setTimeout(() => {
                  _this.initOrderList(_this.data.pageNo, _this.data.pageSize, _this.data.status)
                }, 200)
              }
            } else {
              wx.showToast({
                title: `删除失败!`,
                icon: 'none'
              })
            }
          });
        }
      }
    });
  },
  // 立即支付
  handelToPay(e) {
    const { id, merged } = e.currentTarget.dataset
    let url = merged ? `/sale/payment/merged/buyer/wxprepay/${id}` : `/sale/trade/buyer/wxprepay/${id}`
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    wxService.post(`${url}`).then(res => {
    // wxService.post(`/sale/trade/buyer/wxprepay/${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          let amount = data.amount || 0
          wx.hideLoading()
          wx.requestPayment(Object.assign({
            success(res) {
              wx.hideLoading()
              // 支付成功页面
              wxService.router(`/subPackage/page/pages/paymentStatus/paymentStatus?status=S&amount=${amount}`)
            },
            fail(res) {
              wx.hideLoading()
              wxService.router('/subPackage/page/pages/paymentStatus/paymentStatus?status=F')
            }
          }, data))

        }
      }
    })
  },
  // 查看物流
  checkLogistics(e) {
    let { detail } = e.currentTarget.dataset
    let copyOrderInfo = JSON.parse(JSON.stringify(detail));
    //过滤掉已经退货完的商品
    copyOrderInfo.skuVOList = copyOrderInfo.skuVOList.filter(item => item.canRefundNum > 0);
    //更新可退货数量
    copyOrderInfo.skuVOList.forEach(item => {
      item.totalCount = item.count;
      item.count = item.canRefundNum;
    });


    let obj = {
      id: copyOrderInfo.id,
      logistic: copyOrderInfo.logistic,
      status: copyOrderInfo.status,
    }

    let params = JSON.stringify(obj);
    // 退款申请
    wxService.router(`/pages/logistics/logistics`).search({ params })
  },
  // 查看详情
  handelCheckRfDetail(e) {
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/orderDetail/orderDetail?id=${id}`)
  },
  // 订单详情
  handelDetail(e) {
    // const {detail} = e.currentTarget.dataset
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/orderDetail/orderDetail?id=${id}`)
  },
  // 退单详情 
  handelDetailRf(e) {
    const { id } = e.currentTarget.dataset
    wxService.router(`/pages/refundDetail/refundDetail?id=${id}`)
  },
  // 取消退款
  handelCancelRefund(e) {
    const { id } = e.currentTarget.dataset
    this.handelRevokeRefund(id)
  },
  handelRevokeRefund(id) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = { id }
    wxService.post(`/sale/refund/buyer/cancel?id=${id}`).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          wx.showToast({
            title: '取消退款成功',
          });
          setTimeout(() => {
            this.getRefundList(this.data.pageNo, this.data.pageSize);
          }, 200)
        }
      }
    })
  },

  //点击切换tab
  switchTab(e) {
    const { type, status } = e.currentTarget.dataset
    const { currentIndex } = this.data
    if (currentIndex == type) return false
    this.setData({
      currentIndex: type,
      pageNo: 1,
      orderList: [],
      status: '',
      no_data: true
    }, () => {
      if (type == 5 && status == 'RF') {
        this.getRefundList(this.data.pageNo, this.data.pageSize)
      } else {
        this.setData({
          status: status
        }, () => {
          this.initOrderList(this.data.pageNo, this.data.pageSize, status)
        })

      }
    })
  },

  initOrderList(pageNo, pageSize, status) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = { status: status,orderType:1 }
    wxService.post(`/sale/trade/buyer/history?pageNum=${pageNo}&pageSize=${pageSize}`, params).then(res => {
      if (res) {
        const { result, data } = res.data
        if (result == 0) {
          wx.hideLoading()
          this.setData({
            orderList: this.data.pageNo == 1 ? [...data] : [...this.data.orderList, ...data],
            noMoreFlag: data.length < pageSize ? true : false,
          }, () => {
            this.setData({
              no_data: this.data.orderList.length ? true : false
            })
            // wx.setStorageSync('orderList', this.data.orderList)
          })
        }
      }
    })
  },
  // 退款列表 /refund/buyer/history  订单状态(C:取消;N:新建,A:已审核;R:退货已发R货;D:退货已收货)
  getRefundList(pageNo, pageSize) {
    wx.showLoading({
      title: '加载中',
      mask: true
    })
    const params = {}
    wxService.post(`/sale/refund/buyer/history?pageNum=${pageNo}&pageSize=${pageSize}`, params).then(res => {
      if (res) {
        let { result, data } = res.data
        if (result == 0) {
          wx.hideLoading();
          data = data ? data : [];
          data.forEach(item => {
            let skuList = item.skuList, tradeVOSku = item.tradeVO.skuVOList;
            skuList.forEach(item => {
              let filter = tradeVOSku.filter(c => c.skuId == item.skuId);
              if (filter.length > 0) {
                item.skuImgUrl = filter[0].skuImgUrl;
                item.productName = filter[0].productName;
                item.skuSpec = filter[0].skuSpec;
                item.price = filter[0].price;
                item.count = filter[0].count;
              }
            });
          })

          this.setData({
            orderList: this.data.pageNo == 1 ? [...data] : [...this.data.orderList, ...data],
            noMoreFlag: data.length < pageSize ? true : false
          }, () => {
            this.setData({
              no_data: this.data.orderList.length ? true : false,
            });
          })
        }
      }
    })
  },
  
  //发货之后回调
  onDeliveryOk(){
    this.getRefundList(1,5);
  },
  //填写物流信息
  tapWriteLogis(e) {
    let refundId = e.currentTarget.dataset.id;
    this.setData({
      showApplyRefundModal: true,
      refundId: refundId
    })
  },
  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {
    this.data.pageNo = 1;
    if (this.data.currentIndex == 5){
      this.getRefundList(this.data.pageNo, this.data.pageSize)
    }
    else{
      this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
    }

    setTimeout(() => {
      wx.stopPullDownRefresh();
    },500);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    this.setData({
      pageNo: this.data.pageNo + 1,
    }, () => {
      this.initOrderList(this.data.pageNo, this.data.pageSize, this.data.status)
    })
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  }
})